@@ -6,43 +6,45 @@ DBIx::Schema::Changelog::Driver::SQLite - The great new DBIx::Schema::Changelog:
 
 =head1 VERSION
 
-Version 0.4.0
+Version 0.5.0
 
 =cut
 
-our $VERSION = '0.4.0';
+our $VERSION = '0.5.0';
 
 use strict;
 use warnings;
 use Moose;
+use MooseX::HasDefaults::RO;
 use MooseX::Types::PerlVersion qw( PerlVersion );
+use Method::Signatures::Simple;
 
 with 'DBIx::Schema::Changelog::Driver';
 
 has actions => (
-    is      => 'ro',
     isa     => 'HashRef[Str]',
     default => sub {
         return {
-            create_table => q~CREATE TABLE {0} ( {1} ) WITH ( OIDS=FALSE )~,
-            drop_table   => q~DROP TABLE {0}~,
-            alter_table  => q~ALTER TABLE {0}~,
-            drop_column  => q~DROP COLUMN {0}~,
-            add_column   => q~ADD COLUMN {0}~,
-            create_view  => 'CREATE VIEW {0} AS {1}',
-            drop_view    => 'DROP VIEW {0}',
-            create_index => 'CREATE INDEX idx_{0} ON {1} USING {2} ({3})',
+            create_table   => q~CREATE TABLE {0} ( {1} ) WITH ( OIDS=FALSE )~,
+            drop_table     => q~DROP TABLE {0}~,
+            alter_table    => q~ALTER TABLE {0}~,
+            drop_column    => q~DROP COLUMN {0}~,
+            add_column     => q~ADD COLUMN {0}~,
+            create_view    => 'CREATE VIEW {0} AS {1}',
+            drop_view      => 'DROP VIEW {0}',
+            create_index   => 'CREATE INDEX idx_{0} ON {1} USING {2} ({3})',
+            add_constraint => 'ADD {0}',
             create_sequence =>
 q~CREATE SEQUENCE {0} INCREMENT {1} MINVALUE {2} MAXVALUE {3} START {4} CACHE {5}~,
-            nextval_sequence => q~nextval('{0}'::regclass)~,
+            nextval_sequence => q~DEFAULT nextval('{0}'::regclass)~,
             unique           => q~CONSTRAINT {0} UNIQUE ({1})~,
-            foreign_key  => q~CONSTRAINT {3} FOREIGN KEY ({0}) REFERENCES {1} ({2}) MATCH SIMPLE ON DELETE NO ACTION ON UPDATE NO ACTION~,
+            foreign_key =>
+q~CONSTRAINT {3} FOREIGN KEY ({0}) REFERENCES {1} ({2}) MATCH SIMPLE ON DELETE NO ACTION ON UPDATE NO ACTION~,
         };
     }
 );
 
 has constraints => (
-    is      => 'ro',
     isa     => 'HashRef[Str]',
     default => sub {
         return {
@@ -57,7 +59,6 @@ has constraints => (
 );
 
 has defaults => (
-    is      => 'ro',
     isa     => 'HashRef[Str]',
     default => sub {
         return {
@@ -73,7 +74,6 @@ has defaults => (
 );
 
 has types => (
-    is      => 'ro',
     isa     => 'HashRef[Str]',
     default => sub {
         return {
@@ -150,30 +150,15 @@ has types => (
     }
 );
 
+has select_changelog_table => (
+    isa  => 'Str',
+    lazy => 1,
+    default =>
+"SELECT table_name FROM information_schema.tables WHERE table_schema='public'",
+);
+
 sub _min_version { '9.1' }
 
-=head1 SUBROUTINES/METHODS
-
-=head2 create_changelog_table
-
-=cut
-
-sub create_changelog_table {
-    my ( $self, $dbh, $name ) = @_;
-    my $sth = $dbh->prepare(
-"SELECT table_name FROM information_schema.tables WHERE table_schema='public'"
-    );
-    if ( $sth->execute() or die "Some error $!" ) {
-        foreach ( $sth->fetchrow_array() ) {
-            return undef if ( $_ =~ /^$name$/ );
-        }
-    }
-    return {
-        name    => $name,
-        columns => $self->changelog_table()
-    };
-}
-
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
